package com.ruoyi.system.service;

import java.util.List;
import com.baomidou.mybatisplus.extension.service.IService;
import com.ruoyi.system.domain.DistanceMultiplier;

/**
 * DistanceMultiplierService接口
 * 
 * @author ruoyi
 * @date 2024-08-23
 */
public interface IDistanceMultiplierService extends IService<DistanceMultiplier>
{
    /**
     * 查询DistanceMultiplier
     * 
     * @param id DistanceMultiplier主键
     * @return DistanceMultiplier
     */
    public DistanceMultiplier selectDistanceMultiplierById(Long id);

    /**
     * 查询DistanceMultiplier列表
     * 
     * @param distanceMultiplier DistanceMultiplier
     * @return DistanceMultiplier集合
     */
    public List<DistanceMultiplier> selectDistanceMultiplierList(DistanceMultiplier distanceMultiplier);

    /**
     * 新增DistanceMultiplier
     * 
     * @param distanceMultiplier DistanceMultiplier
     * @return 结果
     */
    public int insertDistanceMultiplier(DistanceMultiplier distanceMultiplier);

    /**
     * 修改DistanceMultiplier
     * 
     * @param distanceMultiplier DistanceMultiplier
     * @return 结果
     */
    public int updateDistanceMultiplier(DistanceMultiplier distanceMultiplier);

    /**
     * 批量删除DistanceMultiplier
     * 
     * @param ids 需要删除的DistanceMultiplier主键集合
     * @return 结果
     */
    public int deleteDistanceMultiplierByIds(Long[] ids);

    /**
     * 删除DistanceMultiplier信息
     * 
     * @param id DistanceMultiplier主键
     * @return 结果
     */
    public int deleteDistanceMultiplierById(Long id);
}
